/* Copyright (c) 2021 Analog Devices, Inc.  All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
  - Redistributions of source code must retain the above copyright notice,
  this list of conditions and the following disclaimer.
  - Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.
  - Modified versions of the software must be conspicuously marked as such.
  - This software is licensed solely and exclusively for use with processors/products
  manufactured by or for Analog Devices, Inc.
  - This software may not be combined or merged with other code in any manner
  that would cause the software to become subject to terms and conditions which
  differ from those listed here.
  - Neither the name of Analog Devices, Inc. nor the names of its contributors
  may be used to endorse or promote products derived from this software without
  specific prior written permission.
  - The use of this software may or may not infringe the patent rights of one or
  more patent holders.  This license does not release you from the requirement
  that you obtain separate licenses from these patent holders to use this software.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL
PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

2021-01-10-7CBSD SLA
*/


/**
 * @file:    calibrate.h
 * @brief:   This file contains  type definitions and function prototype
 *           for calibrate.cpp
 */

#ifndef __CALIBRATE_H__
#define __CALIBRATE_H__

/*============= I N C L U D E S =============*/

#include <stdint.h>

/*============= D E F I N E S =============*/

/**
 * @brief enumeration  for all calibration coeffs
 *
 */
typedef enum
{
    CAL_TYPE_NO_CAL = 0, /**< No Calibration */
    CAL_TYPE_OPEN,       /**< OPEN Calibration*/
    CAL_TYPE_SHORT,      /**< SHORT Calibration */
    CAL_TYPE_LOAD,       /**< LOAD Calibration  */
} CAL_TYPE;


/*============= F U N C T I O N  P R O T O T Y P E S =============*/

/**
 * @details perform specified cal type calibration .
 * @param [in] calType - type of calibration
 * @param [in] stdR - load value for Rt/Load calibration
 * @param [in] stdX - load value for Xt/Load calibration
 * @return ADMX_LCR_STATUS_SUCCESS - Success
 *
 */
int32_t Calibrate(CAL_TYPE calType, float stdR, float stdX);

#endif /* __CALIBRATE_H__ */
